# Generated by Django 3.2.8 on 2021-11-05 09:37

import django.contrib.postgres.indexes
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0005_auto_20211029_1212'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='houses',
            index=django.contrib.postgres.indexes.HashIndex(fields=['objectguid'], name='m3_gar_hous_objectg_c8c379_hash'),
        ),
    ]
