# Generated by Django 3.2.4 on 2021-07-07 13:52

import django.db.models.deletion
from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='admhierarchy',
            name='objectid',
            field=models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='m3_gar.reestrobjects', verbose_name='Глобальный уникальный идентификатор объекта'),
        ),
        migrations.AlterField(
            model_name='munhierarchy',
            name='objectid',
            field=models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='m3_gar.reestrobjects', verbose_name='Глобальный уникальный идентификатор адресного объекта '),
        ),
    ]
