# Generated by Django 3.2.4 on 2021-10-13 11:06

import django.db.models.deletion
from django.db import (
    migrations,
    models,
)


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0003_auto_20210906_0744'),
    ]

    operations = [
        migrations.CreateModel(
            name='AddrObjParams',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False, verbose_name='Идентификатор записи')),
                ('objectid', models.BigIntegerField(verbose_name='Глобальный уникальный идентификатор адресного объекта ')),
                ('changeid', models.BigIntegerField(blank=True, null=True, verbose_name='ID изменившей транзакции')),
                ('changeidend', models.BigIntegerField(verbose_name='ID завершившей транзакции')),
                ('value', models.CharField(max_length=8000, verbose_name='Значение параметра')),
                ('updatedate', models.DateField(verbose_name='Дата внесения (обновления) записи')),
                ('startdate', models.DateField(verbose_name='Дата начала действия записи')),
                ('enddate', models.DateField(verbose_name='Дата окончания действия записи')),
                ('region_code', models.SmallIntegerField(verbose_name='Код региона')),
                ('typeid', models.ForeignKey(db_column='typeid', on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='m3_gar.paramtypes', verbose_name='Тип параметра')),
            ],
            options={
                'verbose_name': 'Параметр',
                'verbose_name_plural': 'Параметры',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ApartmentsParams',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False, verbose_name='Идентификатор записи')),
                ('objectid', models.BigIntegerField(verbose_name='Глобальный уникальный идентификатор адресного объекта ')),
                ('changeid', models.BigIntegerField(blank=True, null=True, verbose_name='ID изменившей транзакции')),
                ('changeidend', models.BigIntegerField(verbose_name='ID завершившей транзакции')),
                ('value', models.CharField(max_length=8000, verbose_name='Значение параметра')),
                ('updatedate', models.DateField(verbose_name='Дата внесения (обновления) записи')),
                ('startdate', models.DateField(verbose_name='Дата начала действия записи')),
                ('enddate', models.DateField(verbose_name='Дата окончания действия записи')),
                ('region_code', models.SmallIntegerField(verbose_name='Код региона')),
                ('typeid', models.ForeignKey(db_column='typeid', on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='m3_gar.paramtypes', verbose_name='Тип параметра')),
            ],
            options={
                'verbose_name': 'Параметр',
                'verbose_name_plural': 'Параметры',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CarplacesParams',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False, verbose_name='Идентификатор записи')),
                ('objectid', models.BigIntegerField(verbose_name='Глобальный уникальный идентификатор адресного объекта ')),
                ('changeid', models.BigIntegerField(blank=True, null=True, verbose_name='ID изменившей транзакции')),
                ('changeidend', models.BigIntegerField(verbose_name='ID завершившей транзакции')),
                ('value', models.CharField(max_length=8000, verbose_name='Значение параметра')),
                ('updatedate', models.DateField(verbose_name='Дата внесения (обновления) записи')),
                ('startdate', models.DateField(verbose_name='Дата начала действия записи')),
                ('enddate', models.DateField(verbose_name='Дата окончания действия записи')),
                ('region_code', models.SmallIntegerField(verbose_name='Код региона')),
                ('typeid', models.ForeignKey(db_column='typeid', on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='m3_gar.paramtypes', verbose_name='Тип параметра')),
            ],
            options={
                'verbose_name': 'Параметр',
                'verbose_name_plural': 'Параметры',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='HousesParams',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False, verbose_name='Идентификатор записи')),
                ('objectid', models.BigIntegerField(verbose_name='Глобальный уникальный идентификатор адресного объекта ')),
                ('changeid', models.BigIntegerField(blank=True, null=True, verbose_name='ID изменившей транзакции')),
                ('changeidend', models.BigIntegerField(verbose_name='ID завершившей транзакции')),
                ('value', models.CharField(max_length=8000, verbose_name='Значение параметра')),
                ('updatedate', models.DateField(verbose_name='Дата внесения (обновления) записи')),
                ('startdate', models.DateField(verbose_name='Дата начала действия записи')),
                ('enddate', models.DateField(verbose_name='Дата окончания действия записи')),
                ('region_code', models.SmallIntegerField(verbose_name='Код региона')),
                ('typeid', models.ForeignKey(db_column='typeid', on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='m3_gar.paramtypes', verbose_name='Тип параметра')),
            ],
            options={
                'verbose_name': 'Параметр',
                'verbose_name_plural': 'Параметры',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='RoomsParams',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False, verbose_name='Идентификатор записи')),
                ('objectid', models.BigIntegerField(verbose_name='Глобальный уникальный идентификатор адресного объекта ')),
                ('changeid', models.BigIntegerField(blank=True, null=True, verbose_name='ID изменившей транзакции')),
                ('changeidend', models.BigIntegerField(verbose_name='ID завершившей транзакции')),
                ('value', models.CharField(max_length=8000, verbose_name='Значение параметра')),
                ('updatedate', models.DateField(verbose_name='Дата внесения (обновления) записи')),
                ('startdate', models.DateField(verbose_name='Дата начала действия записи')),
                ('enddate', models.DateField(verbose_name='Дата окончания действия записи')),
                ('region_code', models.SmallIntegerField(verbose_name='Код региона')),
                ('typeid', models.ForeignKey(db_column='typeid', on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='m3_gar.paramtypes', verbose_name='Тип параметра')),
            ],
            options={
                'verbose_name': 'Параметр',
                'verbose_name_plural': 'Параметры',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SteadsParams',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False, verbose_name='Идентификатор записи')),
                ('objectid', models.BigIntegerField(verbose_name='Глобальный уникальный идентификатор адресного объекта ')),
                ('changeid', models.BigIntegerField(blank=True, null=True, verbose_name='ID изменившей транзакции')),
                ('changeidend', models.BigIntegerField(verbose_name='ID завершившей транзакции')),
                ('value', models.CharField(max_length=8000, verbose_name='Значение параметра')),
                ('updatedate', models.DateField(verbose_name='Дата внесения (обновления) записи')),
                ('startdate', models.DateField(verbose_name='Дата начала действия записи')),
                ('enddate', models.DateField(verbose_name='Дата окончания действия записи')),
                ('region_code', models.SmallIntegerField(verbose_name='Код региона')),
                ('typeid', models.ForeignKey(db_column='typeid', on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='m3_gar.paramtypes', verbose_name='Тип параметра')),
            ],
            options={
                'verbose_name': 'Параметр',
                'verbose_name_plural': 'Параметры',
                'abstract': False,
            },
        ),
        migrations.DeleteModel(
            name='Param',
        ),
    ]
